@@ -14,11 +14,22 @@ if 'BANANA_URL' in os.environ:
         endpoint = os.environ['BANANA_URL']
     print("Hitting endpoint:", endpoint)
 
+direct_call_endpoint = "http://localhost:8000/"
+is_direct = False
+if 'BANANA_SERVER' in os.environ:
+    is_direct = True    
+    if os.getenv("BANANA_SERVER") != "local":
+        direct_call_endpoint = os.getenv("BANANA_SERVER")
+    print("Routing calls directly to server hosted at", direct_call_endpoint)
+
 # THE MAIN FUNCTIONS
 # ___________________________________
 
-
 def run_main(api_key, model_key, model_inputs):
+    # run against self-hosted potassiun server if BANANA_SERVER was set
+    if is_direct:
+        return run_direct(model_inputs)
+
     result = start_api(api_key, model_key, model_inputs)
 
     # likely we get results on first call
@@ -50,6 +61,26 @@ def check_main(api_key, call_id):
 # THE API CALLING FUNCTIONS
 # ________________________
 
+def run_direct(model_inputs):
+    global direct_call_endpoint
+    response = requests.post(direct_call_endpoint, json=model_inputs)
+    if response.status_code != 200:
+        raise Exception("server error: status code: {}\content: {}".format(response.status_code, response.content))
+    try:
+        out = response.json()
+    except:
+        raise Exception("server error: returned invalid json")
+    
+    # We must match the same API as the prod inference server,
+    # so wrap direct API's results in same response shape
+    return {
+        "id": str(uuid4()),
+        "message": "",
+        "created": str(int(time.time())),
+        "apiVersion": "DIRECT",
+        "modelOutputs": [out]
+    }
+
 # Takes in start params and returns the full server json response
 def start_api(api_key, model_key, model_inputs, start_only=False):
     global endpoint
@@ -69,7 +100,6 @@ def start_api(api_key, model_key, model_inputs, start_only=False):
 
     if response.status_code != 200:
         raise Exception("server error: status code {}".format(response.status_code))
-
     try:
         out = response.json()
     except:
